@@ -23,9 +23,30 @@
 
 from .config import VERSION, Var
 from .config import hosts_are_safe, Path
-from .filters import subscribe, subscribe_custom, update, update_all, rename_custom, sync_filter_list_repo, \
-    get_all_filter_lists, unsubscribe, change_permissions, Filter, purge_cache, get_active_filter_lists_count
-from .rules import allow_domains, block_domains, redirect_domains, delete_rules, Rule, get_all_rules, get_rules_count
+from .filters import (
+    subscribe,
+    subscribe_custom,
+    update,
+    update_all,
+    rename_custom,
+    sync_filter_list_repo,
+    get_all_filter_lists,
+    unsubscribe,
+    change_permissions,
+    Filter,
+    purge_cache,
+    get_active_filter_lists_count,
+    get_search_results_filter_lists,
+)
+from .rules import (
+    allow_domains,
+    block_domains,
+    redirect_domains,
+    delete_rules,
+    Rule,
+    get_all_rules,
+    get_rules_count,
+)
 from .const import RulePolicy, USER_RULE_PRIORITY, FilterPermissions, FilterSyntax
 from .hosts import update_hosts, restore_hosts, enable_protection
 from tblock.daemon import start_daemon
@@ -38,7 +59,7 @@ del VERSION
 
 # Specify other metadata
 __url__ = "https://tblock.codeberg.page"
-__license__ = 'GPLv3'
+__license__ = "GPLv3"
 
 # Simplify rule policies
 ALLOW = RulePolicy.ALLOW
