@@ -1,6 +1,12 @@
 # -*- coding: utf-8 -*-
-# TBlock - An anti-capitalist ad-blocker that uses the hosts file
-# Copyright (C) 2021 Twann <twann@ctemplar.com>
+#   _____ ____  _            _
+#  |_   _| __ )| | ___   ___| | __
+#    | | |  _ \| |/ _ \ / __| |/ /
+#    | | | |_) | | (_) | (__|   <
+#    |_| |____/|_|\___/ \___|_|\_\
+#
+# An anti-capitalist ad-blocker that uses the hosts file
+# Copyright (C) 2021-2022 Twann <tw4nn@disroot.org>
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,9 +21,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-if __package__ is None:
-    from ..cli import run_converter
-else:
-    from tblock.cli import run_converter
+# Local modules
+from ..cli import run_converter
 
-run_converter()
+if __name__ == "__main__":
+    run_converter()
