@@ -34,12 +34,18 @@ from .config import Path
 from .style import loading_icon, Icon, Font
 from .const import USER_RULE_PRIORITY, RulePolicy
 from .exceptions import RuleError
-from .utils import is_valid_ip, prompt_user, check_root_access, is_valid_domain, lock_db, unlock_db
+from .utils import (
+    is_valid_ip,
+    prompt_user,
+    check_root_access,
+    is_valid_domain,
+    lock_db,
+    unlock_db,
+)
 from .hosts import update_hosts, remove_from_hosts, add_to_hosts
 
 
 class Rule:
-
     def __init__(self, domain: str, user_rule: bool = False) -> None:
         """
         User rule object
@@ -49,10 +55,11 @@ class Rule:
         self.domain = urllib3.get_host(domain)[1]
         # Fetch rule data from the database
         with sqlite3.connect(Path.RULES_DATABASE) as conn:
-            data = conn.cursor().execute(
-                'SELECT "policy", "ip" FROM r WHERE domain=?;',
-                (self.domain,)
-            ).fetchone()
+            data = (
+                conn.cursor()
+                .execute('SELECT "policy", "ip" FROM r WHERE domain=?;', (self.domain,))
+                .fetchone()
+            )
         self.exists = bool(data)
         self.policy = data[0] if data else None
         self.filter_id = "!user" if data else None
@@ -60,10 +67,14 @@ class Rule:
         self.is_user_rule = True
         if not data and not user_rule:
             with sqlite3.connect(Path.DATABASE) as conn:
-                data = conn.cursor().execute(
-                    'SELECT "policy", "filter_id", "ip" FROM rules WHERE domain=?;',
-                    (self.domain,)
-                ).fetchone()
+                data = (
+                    conn.cursor()
+                    .execute(
+                        'SELECT "policy", "filter_id", "ip" FROM rules WHERE domain=?;',
+                        (self.domain,),
+                    )
+                    .fetchone()
+                )
             self.exists = bool(data)
             self.policy = data[0] if data else None
             self.filter_id = data[1] if data else None
@@ -72,14 +83,22 @@ class Rule:
 
     def wildcard_exists(self) -> bool:
         with sqlite3.connect(Path.RULES_DATABASE) as conn:
-            data = conn.cursor().execute("SELECT domain FROM r WHERE domain LIKE '%*%';")
+            data = conn.cursor().execute(
+                "SELECT domain FROM r WHERE domain LIKE '%*%';"
+            )
         for rule in data:
-            if re.match(re.compile(rule[0].replace(".", "\\.").replace("*", ".*")), self.domain):
+            if re.match(
+                re.compile(rule[0].replace(".", "\\.").replace("*", ".*")), self.domain
+            ):
                 return True
         with sqlite3.connect(Path.DATABASE) as conn:
-            data2 = conn.cursor().execute("SELECT domain FROM rules WHERE domain LIKE '%*%';")
+            data2 = conn.cursor().execute(
+                "SELECT domain FROM rules WHERE domain LIKE '%*%';"
+            )
         for rule in data2:
-            if re.match(re.compile(rule[0].replace(".", "\\.").replace("*", ".*")), self.domain):
+            if re.match(
+                re.compile(rule[0].replace(".", "\\.").replace("*", ".*")), self.domain
+            ):
                 return True
         else:
             return False
@@ -91,13 +110,26 @@ class Rule:
         :param ip: Optional. The bind address domains should be redirected to (only when the policy is redirect)
         :param quiet: Optional. Do not display an output (false by default)
         """
-        if self.exists and self.policy == policy and self.ip == ip and self.filter_id == USER_RULE_PRIORITY:
+        if (
+            self.exists
+            and self.policy == policy
+            and self.ip == ip
+            and self.filter_id == USER_RULE_PRIORITY
+        ):
             if not quiet:
-                print(f" {Icon.WARNING} Exact same rule already exists for domain: {self.domain}")
-        elif not is_valid_domain(self.domain, allow_wildcards=bool(policy == RulePolicy.ALLOW)):
+                print(
+                    f" {Icon.WARNING} Exact same rule already exists for domain: {self.domain}"
+                )
+        elif not is_valid_domain(
+            self.domain, allow_wildcards=bool(policy == RulePolicy.ALLOW)
+        ):
             raise RuleError("Invalid domain rule: {0}".format(self.domain))
         else:
-            if policy == RulePolicy.ALLOW or policy == RulePolicy.BLOCK or policy == RulePolicy.REDIRECT:
+            if (
+                policy == RulePolicy.ALLOW
+                or policy == RulePolicy.BLOCK
+                or policy == RulePolicy.REDIRECT
+            ):
 
                 if policy != RulePolicy.REDIRECT or is_valid_ip(ip):
                     __msg = "Adding rule for domain: {0}".format(self.domain)
@@ -112,19 +144,22 @@ class Rule:
                                 with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
                                         "UPDATE r SET policy=?, ip=? WHERE domain=?;",
-                                        (policy, ip_address.compressed, self.domain)
+                                        (policy, ip_address.compressed, self.domain),
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
                             else:
                                 if self.exists:
                                     with sqlite3.connect(Path.DATABASE) as conn:
-                                        conn.cursor().execute("DELETE FROM rules WHERE domain=?", (self.domain,))
+                                        conn.cursor().execute(
+                                            "DELETE FROM rules WHERE domain=?",
+                                            (self.domain,),
+                                        )
                                 with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
                                         "INSERT INTO r (domain, policy, ip)"
                                         "VALUES (?, ?, ?);",
-                                        (self.domain, policy, ip_address.compressed)
+                                        (self.domain, policy, ip_address.compressed),
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
@@ -134,19 +169,22 @@ class Rule:
                                 with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
                                         "UPDATE r SET policy=?, ip=? WHERE domain=?;",
-                                        (policy, None, self.domain)
+                                        (policy, None, self.domain),
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
                             else:
                                 if self.exists:
                                     with sqlite3.connect(Path.DATABASE) as conn:
-                                        conn.cursor().execute("DELETE FROM rules WHERE domain=?", (self.domain,))
+                                        conn.cursor().execute(
+                                            "DELETE FROM rules WHERE domain=?",
+                                            (self.domain,),
+                                        )
                                 with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
                                         "INSERT INTO r (domain, policy, ip)"
                                         "VALUES (?, ?, ?);",
-                                        (self.domain, policy, None)
+                                        (self.domain, policy, None),
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
@@ -156,7 +194,8 @@ class Rule:
                         if not quiet:
                             print(f" {Icon.ERROR} {__msg}")
                             print(
-                                f" {Icon.WARNING} Wildcard rule already allows domain: {self.domain}")
+                                f" {Icon.WARNING} Wildcard rule already allows domain: {self.domain}"
+                            )
 
                 else:
                     raise RuleError("invalid ip address: {0}".format(ip))
@@ -176,10 +215,7 @@ class Rule:
             if not quiet:
                 print(f" {loading_icon(1)} {__msg}", end="\r")
             with sqlite3.connect(Path.RULES_DATABASE) as conn:
-                conn.cursor().execute(
-                    "DELETE FROM r WHERE domain=?;",
-                    (self.domain,)
-                )
+                conn.cursor().execute("DELETE FROM r WHERE domain=?;", (self.domain,))
                 conn.commit()
             self.__init__(self.domain)
             if not quiet:
@@ -192,20 +228,28 @@ def __remove_allowed_matches(quiet: bool = False) -> dict:
     conn = sqlite3.connect(Path.DATABASE)
     cursor = conn.cursor()
     wildcards = cursor.execute(
-        'SELECT domain FROM rules WHERE policy=? AND domain LIKE "%*%";', (RulePolicy.ALLOW,)
+        'SELECT domain FROM rules WHERE policy=? AND domain LIKE "%*%";',
+        (RulePolicy.ALLOW,),
     ).fetchall()
     conn.close()
     conn = sqlite3.connect(Path.RULES_DATABASE)
     cursor = conn.cursor()
-    wildcards += cursor.execute('SELECT domain FROM r WHERE policy=? AND domain LIKE "%*%";', (RulePolicy.ALLOW,))
+    wildcards += cursor.execute(
+        'SELECT domain FROM r WHERE policy=? AND domain LIKE "%*%";',
+        (RulePolicy.ALLOW,),
+    )
     conn.close()
 
-    cnt = multiprocessing.Value('i', 0)
+    cnt = multiprocessing.Value("i", 0)
 
     with multiprocessing.Pool(initializer=init_globals, initargs=(cnt, quiet)) as pool:
         wildcards_matches = pool.map(check_wildcard_domains, wildcards)
     if not quiet:
-        print(" {0} Checking wildcards rules: {1}/{2}".format(Icon.SUCCESS, cnt.value, len(wildcards)))
+        print(
+            " {0} Checking wildcards rules: {1}/{2}".format(
+                Icon.SUCCESS, cnt.value, len(wildcards)
+            )
+        )
     matches = {}
     for row in wildcards_matches:
         matches.update(row)
@@ -223,11 +267,18 @@ def check_wildcard_domains(i) -> dict:
     matches = {}
     cnt.value += 1
     if not quiet_mode:
-        print(" {0} Checking wildcards rules: {1}".format(loading_icon(cnt.value), cnt.value), end="\r")
+        print(
+            " {0} Checking wildcards rules: {1}".format(
+                loading_icon(cnt.value), cnt.value
+            ),
+            end="\r",
+        )
     conn = sqlite3.connect(Path.DATABASE)
     cursor = conn.cursor()
-    query = cursor.execute("SELECT domain, ip FROM rules WHERE domain LIKE ? AND policy != ?;",
-                           (i[0].replace("*", "%"), RulePolicy.ALLOW)).fetchall()
+    query = cursor.execute(
+        "SELECT domain, ip FROM rules WHERE domain LIKE ? AND policy != ?;",
+        (i[0].replace("*", "%"), RulePolicy.ALLOW),
+    ).fetchall()
     for q in query:
         cursor.execute("DELETE FROM rules WHERE domain=?;", (q[0],))
         matches[q[0]] = q[1]
@@ -235,8 +286,10 @@ def check_wildcard_domains(i) -> dict:
     conn.close()
     conn = sqlite3.connect(Path.RULES_DATABASE)
     cursor = conn.cursor()
-    query = cursor.execute("SELECT domain, ip FROM r WHERE domain LIKE ? AND policy != ?;",
-                           (i[0].replace("*", "%"), RulePolicy.ALLOW)).fetchall()
+    query = cursor.execute(
+        "SELECT domain, ip FROM r WHERE domain LIKE ? AND policy != ?;",
+        (i[0].replace("*", "%"), RulePolicy.ALLOW),
+    ).fetchall()
     for q in query:
         cursor.execute("DELETE FROM r WHERE domain=?;", (q[0],))
         matches[q[0]] = q[1]
@@ -245,8 +298,13 @@ def check_wildcard_domains(i) -> dict:
     return matches
 
 
-def allow_domains(domains: list, do_not_prompt: bool = False, force: bool = False, quiet: bool = False,
-                  also_update_hosts: bool = False) -> None:
+def allow_domains(
+    domains: list,
+    do_not_prompt: bool = False,
+    force: bool = False,
+    quiet: bool = False,
+    also_update_hosts: bool = False,
+) -> None:
     """
     Add allowing user rules for a provided list of domains
     :param domains: The list of domains to allow
@@ -264,7 +322,9 @@ def allow_domains(domains: list, do_not_prompt: bool = False, force: bool = Fals
     lock_db()
 
     # Prompt the user before continuing
-    if do_not_prompt or prompt_user("You are about to allow the following domains:", domains):
+    if do_not_prompt or prompt_user(
+        "You are about to allow the following domains:", domains
+    ):
         wildcards = False
         # Add rules
         domains_list = {}
@@ -289,8 +349,13 @@ def allow_domains(domains: list, do_not_prompt: bool = False, force: bool = Fals
     unlock_db()
 
 
-def block_domains(domains: list, do_not_prompt: bool = False, force: bool = False, quiet: bool = False,
-                  also_update_hosts: bool = False) -> None:
+def block_domains(
+    domains: list,
+    do_not_prompt: bool = False,
+    force: bool = False,
+    quiet: bool = False,
+    also_update_hosts: bool = False,
+) -> None:
     """
     Add blocking user rules for a provided list of domains
     :param domains: The list of domains to block
@@ -308,7 +373,9 @@ def block_domains(domains: list, do_not_prompt: bool = False, force: bool = Fals
     lock_db()
 
     # Prompt the user before continuing
-    if do_not_prompt or prompt_user("You are about to block the following domains:", domains):
+    if do_not_prompt or prompt_user(
+        "You are about to block the following domains:", domains
+    ):
         # Add rules
         if not quiet:
             print(f"{Font.BOLD}==> Adding rules{Font.DEFAULT}")
@@ -327,8 +394,14 @@ def block_domains(domains: list, do_not_prompt: bool = False, force: bool = Fals
     unlock_db()
 
 
-def redirect_domains(domains: list, ip: str, do_not_prompt: bool = False, force: bool = False, quiet: bool = False,
-                     also_update_hosts: bool = False) -> None:
+def redirect_domains(
+    domains: list,
+    ip: str,
+    do_not_prompt: bool = False,
+    force: bool = False,
+    quiet: bool = False,
+    also_update_hosts: bool = False,
+) -> None:
     """
     Add redirecting user rules for a provided list of domains
     :param domains: The list of domains to redirect
@@ -347,7 +420,9 @@ def redirect_domains(domains: list, ip: str, do_not_prompt: bool = False, force:
     lock_db()
 
     # Prompt the user before continuing
-    if do_not_prompt or prompt_user('You are about to redirect the following domains to "{0}":'.format(ip), domains):
+    if do_not_prompt or prompt_user(
+        'You are about to redirect the following domains to "{0}":'.format(ip), domains
+    ):
         # Add rules
         if not quiet:
             print(f"{Font.BOLD}==> Adding rules{Font.DEFAULT}")
@@ -366,8 +441,12 @@ def redirect_domains(domains: list, ip: str, do_not_prompt: bool = False, force:
     unlock_db()
 
 
-def delete_rules(domains: list, do_not_prompt: bool = False, quiet: bool = False,
-                 also_update_hosts: bool = False) -> None:
+def delete_rules(
+    domains: list,
+    do_not_prompt: bool = False,
+    quiet: bool = False,
+    also_update_hosts: bool = False,
+) -> None:
     """
     Delete user rules for a provided list of domains
     :param domains: The list of domains to block
@@ -384,7 +463,9 @@ def delete_rules(domains: list, do_not_prompt: bool = False, quiet: bool = False
     lock_db()
 
     # Prompt the user before continuing
-    if do_not_prompt or prompt_user("You are about to delete the rules of the following domains:", domains):
+    if do_not_prompt or prompt_user(
+        "You are about to delete the rules of the following domains:", domains
+    ):
         domains_list = {}
         # Delete rules
         if not quiet:
@@ -402,12 +483,16 @@ def delete_rules(domains: list, do_not_prompt: bool = False, quiet: bool = False
     unlock_db()
 
 
-def get_all_rules(from_filter_lists: list = None, user_only: bool = False, standard_only: bool = False) -> list:
+def get_all_rules(
+    from_filter_lists: list = None, user_only: bool = False, standard_only: bool = False
+) -> list:
     if from_filter_lists and user_only or user_only and standard_only:
         return []
     elif not os.path.isfile(Path.DATABASE):
-        raise FileNotFoundError("database does not exist yet. "
-                                "Please run 'tblock -Y' with admin privileges to create it")
+        raise FileNotFoundError(
+            "database does not exist yet. "
+            "Please run 'tblock -Y' with admin privileges to create it"
+        )
     else:
         output = []
         data2 = None
@@ -416,7 +501,7 @@ def get_all_rules(from_filter_lists: list = None, user_only: bool = False, stand
                 for f in from_filter_lists:
                     data = conn.cursor().execute(
                         'SELECT "domain" FROM "rules" WHERE filter_id=? ORDER BY domain ASC;',
-                        (f,)
+                        (f,),
                     )
         elif standard_only:
             with sqlite3.connect(Path.DATABASE) as conn:
@@ -446,7 +531,9 @@ def get_all_rules(from_filter_lists: list = None, user_only: bool = False, stand
         return output
 
 
-def list_rules(from_filter_lists: list = None, user_only: bool = False, standard_only: bool = False) -> None:
+def list_rules(
+    from_filter_lists: list = None, user_only: bool = False, standard_only: bool = False
+) -> None:
     """
     List rules stored in the database
 
@@ -457,8 +544,10 @@ def list_rules(from_filter_lists: list = None, user_only: bool = False, standard
     if from_filter_lists and user_only or user_only and standard_only:
         pass
     elif not os.path.isfile(Path.DATABASE):
-        raise FileNotFoundError("database does not exist yet. "
-                                "Please run 'tblock -Y' with admin privileges to create it")
+        raise FileNotFoundError(
+            "database does not exist yet. "
+            "Please run 'tblock -Y' with admin privileges to create it"
+        )
     else:
         data2 = None
         if from_filter_lists:
@@ -466,7 +555,7 @@ def list_rules(from_filter_lists: list = None, user_only: bool = False, standard
                 for f in from_filter_lists:
                     data = conn.cursor().execute(
                         'SELECT "domain", "policy", "ip" FROM "rules" WHERE filter_id=? ORDER BY domain ASC;',
-                        (f,)
+                        (f,),
                     )
         elif standard_only:
             with sqlite3.connect(Path.DATABASE) as conn:
@@ -507,6 +596,6 @@ def list_rules(from_filter_lists: list = None, user_only: bool = False, standard
 
 def get_rules_count() -> int:
     with sqlite3.connect(Path.DATABASE) as db:
-        count = db.cursor().execute('SELECT COUNT() FROM rules;').fetchone()[0]
+        count = db.cursor().execute("SELECT COUNT() FROM rules;").fetchone()[0]
     with sqlite3.connect(Path.RULES_DATABASE) as db:
-        return count + db.cursor().execute('SELECT COUNT() FROM r;').fetchone()[0]
+        return count + db.cursor().execute("SELECT COUNT() FROM r;").fetchone()[0]
