@@ -34,7 +34,7 @@ from .config import VERSION, Path, hosts_are_safe, hosts_are_default
 
 # Compatibility with Windows
 # See: https://codeberg.org/tblock/tblock/pulls/17
-if os.name == 'nt':
+if os.name == "nt":
     # On POSIX, this breaks the colors
     init(convert=True)
 
@@ -66,6 +66,7 @@ def loading_icon(number: int) -> str:
     else:
         return Icon.LOADING_1
 
+
 # These functions are only used to display the status page
 
 
@@ -109,20 +110,28 @@ def repo_version() -> int:
     with sqlite3.connect(Path.DATABASE) as db:
         cursor = db.cursor()
         try:
-            return int(cursor.execute(
-                'SELECT value FROM system WHERE variable="repo_version";'
-            ).fetchone()[0])
+            return int(
+                cursor.execute(
+                    'SELECT value FROM system WHERE variable="repo_version";'
+                ).fetchone()[0]
+            )
         except (IndexError, TypeError):
             return 0
 
 
 def show_status(quiet: bool = False) -> None:
     if not os.path.isfile(Path.DATABASE):
-        raise FileNotFoundError("database does not exist yet. "
-                                "Please run 'tblock -Y' with admin privileges to create it")
+        raise FileNotFoundError(
+            "database does not exist yet. "
+            "Please run 'tblock -Y' with admin privileges to create it"
+        )
     with sqlite3.connect(Path.DATABASE) as db:
-        total_rules = db.cursor().execute('SELECT COUNT() FROM rules;').fetchone()[0]
-        total_filter_lists = db.cursor().execute('SELECT COUNT() FROM filters WHERE subscribing=1;').fetchone()[0]
+        total_rules = db.cursor().execute("SELECT COUNT() FROM rules;").fetchone()[0]
+        total_filter_lists = (
+            db.cursor()
+            .execute("SELECT COUNT() FROM filters WHERE subscribing=1;")
+            .fetchone()[0]
+        )
     if not quiet:
         print(
             f"{Font.BOLD}{Fore.LIGHTMAGENTA_EX}\n"
