@@ -49,9 +49,11 @@ def db_is_locked() -> bool:
 
 def lock_db() -> None:
     if db_is_locked():
-        raise DatabaseLockedError(f"database is locked, please wait for other processes to terminate.\nIf you are sure "
-                                  f"that the daemon or any other instances are not running, you can delete:\n"
-                                  f"-> {Path.DB_LOCK}")
+        raise DatabaseLockedError(
+            f"database is locked, please wait for other processes to terminate.\nIf you are sure "
+            f"that the daemon or any other instances are not running, you can delete:\n"
+            f"-> {Path.DB_LOCK}"
+        )
     else:
         with open(Path.DB_LOCK, "wt") as w:
             w.write(str(os.getpid()))
@@ -70,10 +72,10 @@ def unlock_db() -> None:
 
 def _get_user_consent() -> bool:
     answer = input(":: Are you sure to continue ? [y/n] ")
-    while 'n' != answer.lower() != 'y' and answer != '':
+    while "n" != answer.lower() != "y" and answer != "":
         answer = input(":: Are you sure to continue ? [y/n] ")
     else:
-        return answer.lower() == 'y' or answer == ''
+        return answer.lower() == "y" or answer == ""
 
 
 def is_valid_ip(ip: str) -> bool:
@@ -111,19 +113,19 @@ def prompt_user(message: str, list_of_elements: list = None) -> bool:
         message (str): The message to display
         list_of_elements (list, optional): A list of elements to display
     """
-    output_string = ''
+    output_string = ""
     line_count = 0
     if list_of_elements:
         for item in list_of_elements:
-            if line_count + len(f' {item}') >= 62:
-                output_string += f'\n  {item}'
-                line_count = len(f' {item}')
+            if line_count + len(f" {item}") >= 62:
+                output_string += f"\n  {item}"
+                line_count = len(f" {item}")
             else:
-                output_string += f' {item}'
-                line_count += len(f' {item}')
-    print(f':: {message}')
+                output_string += f" {item}"
+                line_count += len(f" {item}")
+    print(f":: {message}")
     if output_string:
-        print(f'\n {output_string}\n')
+        print(f"\n {output_string}\n")
     try:
         answer = _get_user_consent()
     except KeyboardInterrupt:
@@ -138,7 +140,7 @@ def get_readable_size(bytes_length: float) -> str:
     :param bytes_length: The file size (in Bytes)
     :return: A human-readable format of the file size
     """
-    for unity in ['B', 'KiB', 'MiB', 'GiB', 'TiB']:
+    for unity in ["B", "KiB", "MiB", "GiB", "TiB"]:
         if bytes_length < 1024.0:
             return f"{round(bytes_length,1)} {unity}"
         else:
@@ -151,10 +153,16 @@ def is_url(string: str) -> bool:
     :param string: The string to check
     :return: True if string is a valid URL
     """
-    return bool(re.match(r'(http(s|)|(s|)ftp)://', string))
+    return bool(re.match(r"(http(s|)|(s|)ftp)://", string))
 
 
-def fetch_file(location: str, description: str, output_file: str, quiet: bool = False, sha512sum: str = None) -> bool:
+def fetch_file(
+    location: str,
+    description: str,
+    output_file: str,
+    quiet: bool = False,
+    sha512sum: str = None,
+) -> bool:
     """
     Download or copy a file from the internet or a local directory and display a pretty animation to show progress
     :param location: Web location of the file to download
@@ -165,7 +173,7 @@ def fetch_file(location: str, description: str, output_file: str, quiet: bool =
     :return: True if file has been downloaded successfully.
     """
     headers = {
-        'User-Agent': USER_AGENT,
+        "User-Agent": USER_AGENT,
     }
     __msg = "Fetching {0}".format(description)
     if is_url(location):
@@ -174,33 +182,37 @@ def fetch_file(location: str, description: str, output_file: str, quiet: bool =
             response = requests.get(location, stream=True, headers=headers, timeout=8)
             if response.status_code != 200:
                 raise TBlockNetworkError("status code is not 200")
-            online_size = int(response.headers.get('content-length', 0))
+            online_size = int(response.headers.get("content-length", 0))
             online_size_readable = get_readable_size(online_size)
 
             local_size = 0
             count = 0
 
-            with open(output_file, 'wb') as f:
+            with open(output_file, "wb") as f:
                 for data in response.iter_content(1024):
                     count += 1
                     local_size += 1024
                     if online_size != 0:
                         percent = int(local_size * 100 / online_size)
                     else:
-                        percent = '- '
+                        percent = "- "
                     if not quiet:
-                        print(f" {loading_icon(count)} {__msg} ({online_size_readable}): {percent}%",
-                              end="\r")
+                        print(
+                            f" {loading_icon(count)} {__msg} ({online_size_readable}): {percent}%",
+                            end="\r",
+                        )
                     f.write(data)
 
             with open(output_file, "rb") as f:
                 local_size = len(f.read())
             if not quiet:
-                print(f" {Icon.SUCCESS} {__msg} ({get_readable_size(local_size)}): 100%")
+                print(
+                    f" {Icon.SUCCESS} {__msg} ({get_readable_size(local_size)}): 100%"
+                )
             if sha512sum is not None:
                 if not quiet:
-                    print(f" {loading_icon(1)} Checking hash", end='\r')
-                with open(output_file, 'rb') as r:
+                    print(f" {loading_icon(1)} Checking hash", end="\r")
+                with open(output_file, "rb") as r:
                     hash = hashlib.sha512(r.read()).hexdigest()
                 if hash == sha512sum:
                     if not quiet:
@@ -213,8 +225,14 @@ def fetch_file(location: str, description: str, output_file: str, quiet: bool =
             else:
                 return True
 
-        except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
-                urllib3.exceptions.NewConnectionError, TBlockNetworkError, requests.exceptions.ReadTimeout):
+        except (
+            requests.exceptions.ConnectionError,
+            urllib3.exceptions.MaxRetryError,
+            ConnectionRefusedError,
+            urllib3.exceptions.NewConnectionError,
+            TBlockNetworkError,
+            requests.exceptions.ReadTimeout,
+        ):
             if not quiet:
                 print(f" {Icon.ERROR} {__msg} (0 B): 0%")
             return False
@@ -225,14 +243,16 @@ def fetch_file(location: str, description: str, output_file: str, quiet: bool =
                 online_size = len(f.read())
             online_size_readable = get_readable_size(online_size)
             if not quiet:
-                print(f" {loading_icon(1)} {__msg} ({online_size_readable}): 0%", end="\r")
+                print(
+                    f" {loading_icon(1)} {__msg} ({online_size_readable}): 0%", end="\r"
+                )
             shutil.copy(location, output_file, follow_symlinks=True)
             if not quiet:
                 print(f" {Icon.SUCCESS} {__msg} ({online_size_readable}): 100%")
             if sha512sum is not None:
                 if not quiet:
-                    print(f" {loading_icon(1)} Checking hash", end='\r')
-                with open(output_file, 'rb') as r:
+                    print(f" {loading_icon(1)} Checking hash", end="\r")
+                with open(output_file, "rb") as r:
                     hash = hashlib.sha512(r.read()).hexdigest()
                 if hash == sha512sum:
                     if not quiet:
